pub enum SmtError {
CorruptedData {
key: String,
condition: String,
},
ByteLevelError(TypeError),
Datastorage(StorageError),
FailedMerge {
error: String,
},
IllogicalState {
failstate: String,
},
NoLeavesProvided {
function: String,
key_option: String,
},
NotFound {
key: String,
},
ProofAssemblyError {
error: String,
},
}Variants
CorruptedData
Used whenever a node is read with no coherent data.
ByteLevelError(TypeError)
Datastorage(StorageError)
Used whenever there is an issue executing task in the datastorage.
FailedMerge
Informs that a merge between 2 keys was not possible.
IllogicalState
The library reaches a state in which it does not have any way to recover nor proceed.
NoLeavesProvided
Informs that a function that requires at least one leaf was provided with None.
NotFound
Informs that some critical node was not found in the datastorage.
ProofAssemblyError
Informs that some node was not found inside the main proof, hence the proof assembly process is no longer allowed to proceed.