Node

Struct Node 

pub struct Node<T> { /* private fields */ }

Implementations

Source

impl<T> Node<T>

pub fn new( key: T, depth: u16, index_len: u16, index: Option<T>, left_child: Option<T>, right_child: Option<T>, ) -> Node<T>

Creates a new node object with the given parameters.

Arguments
  • key - Key value of the node.
  • depth - Index depth: first useful bit of its index.
  • index_len - Number of useful index bits. This value is not used for leaves.
  • index - Index it is representing.
  • left_child - For nodes it represents the key of its left child and for leaves its own key.
  • right_child - For nodes it represents the key of its right child and for leaves its own key.
pub fn is_leaf(&self) -> bool

Returns a boolean value that tells if it represents a leaf.

pub fn is_root(&self) -> bool

Returns a boolean value that tells if it represents the root. For a node to be a root it must:

  • Have depth == 0 &&
  • Have index_len== 0 &&
  • Not be a leaf
pub fn is_intermediate(&self) -> bool

Returns a boolean value that tells if it represents a intermediate node. For a node to be intermediate it must:

  • Not be a leaf.
  • Not be a root.
pub fn get_key(&self) -> &T

Returns a reference to the key representing the node calculated by merging its childs.

pub fn get_depth(&self) -> &u16

Returns the first useful bit of the node index.

pub fn set_depth(&mut self, depth: u16)

Sets the first useful bit of the node index.

pub fn get_index_length(&self) -> &u16

Returns the first useful bits of the node index.

pub fn set_index_length(&mut self, index_len: u16)

Sets the amount of useful bits of the node index.

pub fn get_index(&self) -> &Option<T>

Returns the node index.

pub fn get_left_child(&self) -> &Option<T>

Returns the key of the left child. It will be None if the node represents a leaf.

pub fn get_right_child(&self) -> &Option<T>

Returns the key of the right child. It will be None if the node represents a leaf.